@@ -1,6 +1,10 @@
 from .errors import CompressionError
 from .errors import VersionError
 from .errors import ParsingError
+
 from .retrievers import BaseStruct
 from .retrievers import Retriever
-from .retrievers import MapValidate
+from .retrievers import RetrieverRef
+from .retrievers import RetrieverCombiner
+
+from .utils import Version
